
[![Build Status](https://travis-ci.org/klittlepage/hgpmatch.svg?branch=master)](https://travis-ci.org/klittlepage/hgpmatch)
[![Documentation Status](https://readthedocs.org/projects/hgpmatch/badge/?version=latest)](https://hgpmatch.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/klittlepage/hgpmatch/badge.svg?branch=master)](https://coveralls.io/github/klittlepage/hgpmatch?branch=master)

# Project Documentation

Documentation on `hgpmatch` lives [here](https://hgpmatch.readthedocs.io/).
